import json
import os

from adapay_core import log_util
from adapay_core.log_util import log_error
from adapay_core.param_handler import read_file

import adapay

config_path = None
api_key = None
private_key = None
public_key = None
"""
全局的配置字典
{"member_id1":{},
 "member_id2":{},
 "member_id3":{},
   ···
}
"""
global_config_dict = None

from fishbase.fish_logger import set_log_file, set_log_stdout

base_url = 'https://api.adapay.tech'
connect_timeout = 30


def init_log(console_enable=False, log_level='', log_tag='{adapay}', log_file_path=''):
    """
    :param log_tag:
    :param log_level:
    :param console_enable: 是否在控台输出日志
    :param log_file_path:
    :return:
    """
    if console_enable:
        set_log_stdout()
    if log_file_path:
        set_log_file(log_file_path)
    if log_level:
        log_util.log_level = log_level
        if log_tag:
            log_util.log_tag = log_tag


def init_config(member_id, is_prod=True):
    if not config_path:
        log_error('config_path is empty')
        return

    if not member_id:
        log_error('member_id is empty')
        return

    total_config_dict = adapay.global_config_dict
    if not total_config_dict:
        total_config_dict = dict()

    single_config_dict = total_config_dict.get(member_id)

    if not single_config_dict:
        config_json = read_file(config_path + os.sep + member_id + '.json')
        single_config_dict = json.loads(config_json)
        total_config_dict.update({member_id: single_config_dict})

    if is_prod:
        adapay.api_key = single_config_dict.get("api_key_live")
    else:
        adapay.api_key = single_config_dict.get("api_key_test")

    adapay.private_key = single_config_dict.get("rsa_private_key")
    adapay.public_key = read_file(os.path.dirname(__file__) + os.sep + 'public_key.pem')


__version__ = '1.1.1'

from adapay.api import *



from adapay.api.payment import Payment
from adapay.api.refund import Refund
from adapay.api.bill import Bill
from adapay.api.member import Member
from adapay.api.corp_member import CorpMember
from adapay.api.account import Account
from adapay.api.user import User
from adapay.api.wallet import Wallet



import adapay
from adapay_core import ApiRequest

pay_message_token = '/v1/token/apply'

payment_create = '/v1/payments'
payment_confirm = '/v1/payments/confirm'
payment_confirm_query = '/v1/payments/confirm/{payment_confirm_id}'
payment_confirm_query_list = '/v1/payments/confirm/list'
payment_reverse = '/v1/payments/reverse'
payment_reverse_query = '/v1/payments/reverse/{reverse_id}'
payment_reverse_query_list = '/v1/payments/reverse/list'
payment_query = '/v1/payments/{payment_id}'
payment_close = '/v1/payments/{}/close'

refund_create = '/v1/payments/{}/refunds'
refund_query = '/v1/payments/refunds'

bill_download = '/v1/bill/download'

member_create = '/v1/members'
member_query = '/v1/members/{member_id}'
member_query_list = '/v1/members/list'
member_update = '/v1/members/update'
corp_member_create = '/v1/corp_members'
corp_member_query = '/v1/corp_members/{member_id}'

settle_account_create = '/v1/settle_accounts'
settle_account_modify = '/v1/settle_accounts/modify'
settle_account_query = '/v1/settle_accounts/{settle_account_id}'
settle_account_delete = '/v1/settle_accounts/delete'
settle_account_detail_query = '/v1/settle_accounts/settle_details'
settle_account_balance_query = '/v1/settle_accounts/balance'
settle_account_cash_draw = '/v1/cashs'
cash_draw_status = '/v1/cashs/stat'

query_identity = '/v1/union/user_identity'

wallet_login = '/v1/walletLogin'
wallet_pay = '/v1/account/payment'
wallet_checkout = '/v1/checkout'


def __request_init(url, request_params, base_url):
    ApiRequest.base_url = base_url if base_url else adapay.base_url
    ApiRequest.build(adapay.api_key, adapay.private_key, adapay.public_key, url, request_params, adapay.__version__,
                     adapay.connect_timeout)


def request_post(url, request_params, files=None, base_url=''):
    __request_init(url, request_params, base_url)
    return ApiRequest.post(files)


def request_get(url, request_params, base_url=''):
    __request_init(url, request_params, base_url)
    return ApiRequest.get()



from adapay.api import request_tools
from adapay.api.request_tools import request_post, request_get


class Account(object):

    @classmethod
    def create_settle(cls, **kwargs):
        """
        创建结算账户
        """
        return request_post(request_tools.settle_account_create, kwargs)

    @classmethod
    def query_settle(cls, **kwargs):
        """
        查询结算账户
        """
        url = request_tools.settle_account_query.format(settle_account_id=kwargs.get('settle_account_id'))
        return request_get(url, kwargs)

    @classmethod
    def modify_settle(cls, **kwargs):
        """
        修改结算配置
        """
        return request_post(request_tools.settle_account_modify, kwargs)

    @classmethod
    def delete_settle(cls, **kwargs):
        """
        删除结算账户
        """
        return request_post(request_tools.settle_account_delete, kwargs)

    @classmethod
    def query_settle_details(cls, **kwargs):
        """
        查询结算账户明细
        """
        return request_get(request_tools.settle_account_detail_query, kwargs)

    @classmethod
    def query_balance(cls, **kwargs):
        """
        查询账户余额
        """
        return request_get(request_tools.settle_account_balance_query, kwargs)

    @classmethod
    def draw_cash(cls, **kwargs):
        """
        取现
        """
        return request_post(request_tools.settle_account_cash_draw, kwargs)

    @classmethod
    def query_draw_cash_status(cls, **kwargs):
        """
        取现状态查询
        """
        return request_get(request_tools.cash_draw_status, kwargs)





from adapay.api import request_tools
from adapay.api.request_tools import request_post


class User(object):

    @classmethod
    def query_union_identity(cls, **kwargs):
        return request_post(request_tools.query_identity, kwargs)





"""
2019.8.1 create by yumin.chang
调用支付接口
"""
from adapay.api.request_tools import payment_create, payment_query, payment_close, payment_reverse, \
    payment_reverse_query_list, payment_confirm, payment_confirm_query, payment_confirm_query_list, \
    payment_reverse_query, request_post, request_get


class Payment(object):

    @classmethod
    def create(cls, **kwargs):
        """
        创建订单
        """
        if not kwargs.get('currency'):
            kwargs['currency'] = 'cny'

        return request_post(payment_create, kwargs)

    @classmethod
    def create_confirm(cls, **kwargs):
        """
        创建订单确认
        """
        return request_post(payment_confirm, kwargs)

    @classmethod
    def query_confirm(cls, **kwargs):
        """
        查询订单确认
        """
        url = payment_confirm_query.format(payment_confirm_id=kwargs.get('payment_confirm_id'))
        return request_get(url, kwargs)

    @classmethod
    def query_confirm_list(cls, **kwargs):
        """
         查询订单确认列表
        """
        return request_get(payment_confirm_query_list, kwargs)

    @classmethod
    def create_reverse(cls, **kwargs):
        """
        支付撤销
        """
        return request_post(payment_reverse, kwargs)

    @classmethod
    def query_reverse(cls, **kwargs):
        """
        查询支付撤销
        """
        url = payment_reverse_query.format(reverse_id=kwargs.get('reverse_id'))
        return request_get(url, kwargs)

    @classmethod
    def query_reverse_list(cls, **kwargs):
        """
        查询支付撤销列表
        """
        return request_get(payment_reverse_query_list, kwargs)

    @classmethod
    def query(cls, **kwargs):
        """
        支付查询
        """
        url = payment_query.format(payment_id=kwargs.get('payment_id'))
        return request_get(url, kwargs)

    @classmethod
    def close(cls, **kwargs):
        """
        关单请求
        """
        url = payment_close.format(kwargs['payment_id'])
        return request_post(url, kwargs)





import adapay
from adapay.api.request_tools import request_post, pay_message_token
from adapay_core.log_util import log_info
from adapay_core.pay_message import AdapayMessage


def get_message_manager():
    expire_time = 30_000_000_000
    data = request_post(pay_message_token, {'expire_time': expire_time})

    if 'succeeded' != data.get('status'):
        log_info('token request failed')

    return AdapayMessage(adapay.api_key, data.get('token', ''))



from adapay.api import request_tools
from adapay.api.request_tools import request_post


class Wallet(object):
    wallet_base_url = 'https://page.adapay.tech'

    @classmethod
    def login(cls, **kwargs):
        """
        钱包用户登录
        :param kwargs:
        :return:
        """
        return request_post(request_tools.wallet_login, kwargs, base_url=Wallet.wallet_base_url)

    @classmethod
    def pay(cls, **kwargs):
        """
        钱包支付
        :param kwargs:
        :return:
        """
        return request_post(request_tools.wallet_pay, kwargs, base_url=Wallet.wallet_base_url)

    @classmethod
    def checkout(cls, **kwargs):
        """
        创建收银台对象
        :param kwargs:
        :return:
        """
        return request_post(request_tools.wallet_checkout, kwargs, base_url=Wallet.wallet_base_url)





from adapay.api import request_tools
from adapay.api.request_tools import request_post


class Bill(object):

    @classmethod
    def download(cls, **kwargs):
        return request_post(request_tools.bill_download, kwargs)


